@@ -1,5 +1,6 @@
 # -*- cperl; cperl-indent-level: 4 -*-
-package WWW::Wookie::Connector::Service v1.1.1;
+# Copyright (C) 2010-2021, Roland van Ipenburg
+package WWW::Wookie::Connector::Service v1.1.2;
 use strict;
 use warnings;
 
@@ -88,8 +89,8 @@ Log::Log4perl::easy_init($ERROR);
 ## use critic
 
 has '_logger' => (
-    'is'  => 'ro',
-    'isa' => 'Log::Log4perl::Logger',
+    'is'      => 'ro',
+    'isa'     => 'Log::Log4perl::Logger',
     'default' =>
       sub { Log::Log4perl->get_logger('WWW::Wookie::Connector::Service') },
     'reader' => 'getLogger',
@@ -120,7 +121,7 @@ sub getAvailableServices {
         $url .= $SLASH . URI::Escape::uri_escape($service_name);
     }
     if ( $self->getLocale ) {
-        $content->{'locale'} = $self->getLocale;
+        ${$content}{'locale'} = $self->getLocale;
     }
 
     my %services = ();
@@ -129,10 +130,10 @@ sub getAvailableServices {
         'ForceArray' => 1,
         'KeyAttr'    => { 'widget' => q{id}, 'service' => q{name} },
     )->XMLin( $response->content );
-    while ( my ( $name, $value ) = each %{ $xml_obj->{'service'} } ) {
+    while ( my ( $name, $value ) = each %{ ${$xml_obj}{'service'} } ) {
         $self->getLogger->debug($name);
         my $service = WWW::Wookie::Widget::Category->new( 'name' => $name );
-        while ( my ( $id, $value ) = each %{ $value->{'widget'} } ) {
+        while ( my ( $id, $value ) = each %{ ${$value}{'widget'} } ) {
             $service->put(
                 WWW::Wookie::Widget->new( $id, $self->_parse_widget($value) ) );
         }
@@ -150,13 +151,13 @@ sub getAvailableWidgets {
     my $content = {};
     if ( !defined $service || $service eq $ALL ) {
         $self->getLogger->debug( $LOG{'ALL_TRUE'} );
-        $content->{'all'} = q{true};
+        ${$content}{'all'} = q{true};
     }
     elsif ($service) {
         $url .= $SLASH . URI::Escape::uri_escape($service);
     }
     if ( $self->getLocale ) {
-        $content->{'locale'} = $self->getLocale;
+        ${$content}{'locale'} = $self->getLocale;
     }
     __check_url( $url, $ERR{'MALFORMED_URL'} );
 
@@ -164,10 +165,10 @@ sub getAvailableWidgets {
     my $xml_obj =
       XML::Simple->new( 'ForceArray' => 1, 'KeyAttr' => 'id' )
       ->XMLin( $response->content );
-    while ( my ( $id, $value ) = each %{ $xml_obj->{'widget'} } ) {
+    while ( my ( $id, $value ) = each %{ ${$xml_obj}{'widget'} } ) {
         $widgets{$id} =
           WWW::Wookie::Widget->new( $id,
-            $self->_parse_widget( $xml_obj->{'widget'}->{$id} ) );
+            $self->_parse_widget( ${ ${$xml_obj}{'widget'} }{$id} ) );
     }
     return values %widgets;
 }
@@ -247,7 +248,7 @@ sub getOrCreateInstance {
         __check_url( $url, $ERR{'MALFORMED_URL'} );
         my $content = { 'widgetid' => $guid };
         if ( my $locale = $self->getLocale ) {
-            $content->{'locale'} = $locale;
+            ${$content}{'locale'} = $locale;
         }
         my $response = $self->_do_request( $url, $content );
         if ( $response->code == HTTP_CREATED ) {
@@ -294,11 +295,11 @@ sub getUsers {
       XML::Simple->new( 'ForceArray' => 1, 'KeyAttr' => 'id' )
       ->XMLin( $response->content );
     my @users = ();
-    while ( my ( $id, $value ) = each %{ $xml_obj->{'participant'} } ) {
+    while ( my ( $id, $value ) = each %{ ${$xml_obj}{'participant'} } ) {
         my $new_user = WWW::Wookie::User->new(
             $id,
-            defined $value->{'displayName'}   || $id,
-            defined $value->{'thumbnail_url'} || $EMPTY,
+            defined ${$value}{'displayName'}   || $id,
+            defined ${$value}{'thumbnail_url'} || $EMPTY,
         );
         push @users, $new_user;
     }
@@ -616,9 +617,9 @@ sub _parse_instance {
       XML::Simple->new( 'ForceArray' => 1, 'KeyAttr' => 'id' )->XMLin($xml);
     if (
         my $instance = WWW::Wookie::Widget::Instance->new(
-            $xml_obj->{'url'}[0],   $guid,
-            $xml_obj->{'title'}[0], $xml_obj->{'height'}[0],
-            $xml_obj->{'width'}[0],
+            ${$xml_obj}{'url'}[0],   $guid,
+            ${$xml_obj}{'title'}[0], ${$xml_obj}{'height'}[0],
+            ${$xml_obj}{'width'}[0],
         )
       )
     {
@@ -631,15 +632,15 @@ sub _parse_instance {
 
 sub _parse_widget {
     my ( $self, $xml ) = @_;
-    my $title = $xml->{'name'}[0]->{'content'};
+    my $title = ${ ${$xml}{'name'}[0] }{'content'};
     my $description =
-      ref $xml->{'description'}[0]
-      ? $xml->{'description'}[0]->{'content'}
-      : $xml->{'description'}[0];
+      ref ${$xml}{'description'}[0]
+      ? ${ ${$xml}{'description'}[0] }{'content'}
+      : ${$xml}{'description'}[0];
     my $icon =
-      ref $xml->{'icon'}[0]
-      ? $xml->{'icon'}[0]->{'content'}
-      : $xml->{'icon'}[0];
+      ref ${$xml}{'icon'}[0]
+      ? ${ ${$xml}{'icon'}[0] }{'content'}
+      : ${$xml}{'icon'}[0];
     if ( !$icon ) {
         $icon = $DEFAULT_ICON;
     }
@@ -658,7 +659,7 @@ __END__
 
 =encoding utf8
 
-=for stopwords API Readonly Wookie guid Ipenburg login MERCHANTABILITY
+=for stopwords Bitbucket API Readonly Wookie guid Ipenburg login MERCHANTABILITY
 
 =head1 NAME
 
@@ -667,7 +668,7 @@ data requests and responses
 
 =head1 VERSION
 
-This document describes WWW::Wookie::Connector::Service version v1.1.1
+This document describes WWW::Wookie::Connector::Service version C<v1.1.2>
 
 =head1 SYNOPSIS
 
@@ -884,6 +885,10 @@ Set a locale.
 
 Get the current locale setting. Returns current locale as string.
 
+=head2 C<BUILD>
+
+The Moose internal BUILD method.
+
 =head1 CONFIGURATION AND ENVIRONMENT
 
 =head1 DEPENDENCIES
@@ -936,16 +941,16 @@ Get the current locale setting. Returns current locale as string.
 
 =head1 BUGS AND LIMITATIONS
 
-Please report any bugs or feature requests at L<RT for
-rt.cpan.org|https://rt.cpan.org/Dist/Display.html?Queue=WWW-Wookie>.
+Please report any bugs or feature requests at
+L<Bitbucket|https://bitbucket.org/rolandvanipenburg/www-wookie/issues>.
 
 =head1 AUTHOR
 
-Roland van Ipenburg, E<lt>ipenburg@xs4all.nlE<gt>
+Roland van Ipenburg, E<lt>roland@rolandvanipenburg.comE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2017 by Roland van Ipenburg
+Copyright 2010-2021 by Roland van Ipenburg
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.14.0 or,
