@@ -1,4 +1,5 @@
 # -*- cperl; cperl-indent-level: 4 -*-
+# Copyright (C) 2010-2021, Roland van Ipenburg
 package WWW::Wookie::Connector::Service::Interface;
 use strict;
 use warnings;
@@ -6,7 +7,7 @@ use warnings;
 use utf8;
 use 5.020000;
 
-our $VERSION = 'v1.1.1';
+our $VERSION = 'v1.1.2';
 
 use Moose::Role qw/requires/;
 requires 'getAvailableServices';
@@ -32,7 +33,7 @@ __END__
 
 =encoding utf8
 
-=for stopwords Wookie guid Ipenburg MERCHANTABILITY
+=for stopwords Bitbucket Wookie guid Ipenburg MERCHANTABILITY
 
 =head1 NAME
 
@@ -42,7 +43,7 @@ L<WWW::Wookie::Connector::Service|WWW::Wookie::Connector::Service>
 =head1 VERSION
 
 This document describes WWW::Wookie::Connector::Service::Interface version
-v1.1.1
+C<v1.1.2>
 
 =head1 SYNOPSIS
 
@@ -251,16 +252,16 @@ L<Moose::Role|Moose::Role>
 
 =head1 BUGS AND LIMITATIONS
 
-Please report any bugs or feature requests at L<RT for
-rt.cpan.org|https://rt.cpan.org/Dist/Display.html?Queue=WWW-Wookie>.
+Please report any bugs or feature requests at
+L<Bitbucket|https://bitbucket.org/rolandvanipenburg/www-wookie/issues>.
 
 =head1 AUTHOR
 
-Roland van Ipenburg, E<lt>ipenburg@xs4all.nlE<gt>
+Roland van Ipenburg, E<lt>roland@rolandvanipenburg.comE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2017 by Roland van Ipenburg
+Copyright 2010-2021 by Roland van Ipenburg
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.14.0 or,
