@@ -1,5 +1,6 @@
 # -*- cperl; cperl-indent-level: 4 -*-
-package WWW::Wookie::Widget::Property v1.1.1;
+# Copyright (C) 2010-2021, Roland van Ipenburg
+package WWW::Wookie::Widget::Property v1.1.2;
 use strict;
 use warnings;
 
@@ -65,7 +66,7 @@ __END__
 
 =encoding utf8
 
-=for stopwords boolean Readonly Ipenburg MERCHANTABILITY
+=for stopwords Bitbucket boolean Readonly Ipenburg MERCHANTABILITY
 
 =head1 NAME
 
@@ -73,7 +74,7 @@ WWW::Wookie::Widget::Property - Property class
 
 =head1 VERSION
 
-This document describes WWW::Wookie::Widget::Property version v1.1.1
+This document describes WWW::Wookie::Widget::Property version C<v1.1.2>
 
 =head1 SYNOPSIS
 
@@ -161,16 +162,16 @@ Set C<isPublic> flag, 1 or 0.
 
 =head1 BUGS AND LIMITATIONS
 
-Please report any bugs or feature requests at L<RT for
-rt.cpan.org|https://rt.cpan.org/Dist/Display.html?Queue=WWW-Wookie>.
+Please report any bugs or feature requests at
+L<Bitbucket|https://bitbucket.org/rolandvanipenburg/www-wookie/issues>.
 
 =head1 AUTHOR
 
-Roland van Ipenburg, E<lt>ipenburg@xs4all.nlE<gt>
+Roland van Ipenburg, E<lt>roland@rolandvanipenburg.comE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2017 by Roland van Ipenburg
+Copyright 2010-2021 by Roland van Ipenburg
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.14.0 or,
